
# Reads Phylip format from MCCOAL, like this
# 
# 8 1000 
# a1^A        GCGGGATACG CCGACGTTGC TAAGAGACAT CAAG
# a2^A        GCGGGATACG CCGACGTTGC TAAGAGACAT CCAG
#  ...
# d2^D        GCGGGATACG CCGACGTTGC TAAGAGACAT CCAG
# ...
# 8 1000 
# a1^A        AAACGATCGA
# ... 


# and writes data section of BEAST XML like this

# 
# <data
# id="s4i4locus4"
# name="alignment">
#   <sequence id="seq_a01_A4" taxon="a01_A" totalcount="4" value="?"/>
#   <sequence id="seq_a02_A4" taxon="a02_A" totalcount="4" value="?"/>
#   ...
#   

dpath <- "C:/Users/GRJ/AAA/Programming/Biology/Simulations/DENIMtests/DENIMtestsDec20"


convert <- function(mcseqs.fpath) {
  mcseqs.lines <- readLines(con = mcseqs.fpath)
  mcseqs.lines <- trimws(mcseqs.lines)
  mcseqs.lines <- mcseqs.lines[which(nchar(mcseqs.lines) >0)]
  
  ln <- 1
  locus <- 1
  while (ln < length(mcseqs.lines)) {
    cat("\t<data\n")
    counts <- strsplit(mcseqs.lines[ln], "[[:blank:]]")[[1]]
    counts <- as.integer(counts)
    stopifnot(length(counts) == 2)
    stopifnot(is.finite(counts[1]))
    stopifnot(is.finite(counts[2]))
    stopifnot(counts[1] > 0)
    stopifnot(counts[2] > 0)
    cat("\tid=", "\"s4i4locus", locus, "\"\n", sep="")
    cat("\tname=", "\"alignment\">\n", sep="")
    for (s in 1:counts[1]) {
      seq.line <- mcseqs.lines[ln + s]
      seq.bits <- strsplit(seq.line, "[[:blank:]]")[[1]]
      taxon <- seq.bits[1]
      seq <- paste0(seq.bits[-1], collapse="")
      stopifnot(nchar(seq) == counts[2])
      cat("\t\t<sequence id=",  "\"seq_", taxon, "_", locus, "\"",
          " taxon=",  "\"", taxon, "\"",
          " totalcount=\"4\" value=\"", seq, "\"/>\n", sep="")
    }
    ln <- ln + counts[1] + 1
    locus <- locus + 1 
    cat("\t</data>\n")
  }
}


sink(paste0(dpath, "/mcseqs.xml"))
convert(paste0(dpath, "/mcseqs.txt"))
sink(NULL)



